---
feature_story: FS_33_76_82_84
feature_title: composite forest
feature_status: TEST
---
Keywords: `composite`, `tree`, `composite_tree`, `forest`, `composite_forest`

This feature hides (nearly obsoletes) and combines:
*   FS_42_76_93_51 very first zero arg
*   FS_01_89_09_24 interp tree
*   FS_26_43_73_72 func tree
*   FS_91_88_07_23 jump tree

# General idea

The idea is that there should be a single tree view (composite forest) configured for server navigation
instead of sub-tree parts distributed across many plugin configs.

# Implementation

The composite forest is configured according to `CompositeForestSchema`.

Various info (in data structure suitable for various special purposes) is
extracted from the composite forest via `CompositeForestExtractor`.
